@@ -350,6 +350,12 @@ def hook_six(finder, module):
                     None, "six.moves", finder._optimize)
     finder._add_module("six.moves", m)
 
+def hook_infi(finder, module):
+    """Thw whole infi namespace package relies on pkg_resources for
+    loading modules and data files.
+    """
+    finder.import_hook("pkg_resources")
+
 def hook_matplotlib(finder, module):
     """matplotlib requires data files in a 'mpl-data' subdirectory in
     the same directory as the executable.
@@ -585,6 +591,13 @@ def hook_pandas(finder, module):
         finder.import_hook("pandas._libs.tslibs.base")
         finder.recursion_depth_pandas = depth
 
+def hook_pkg_resources(finder, module):
+    depth = getattr(finder,"recursion_depth_pkg_resources", 0)
+    if depth==0:
+        finder.recursion_depth_pkg_resources = depth + 1
+        finder.import_package("pkg_resources._vendor")
+        finder.recursion_depth_pkg_resources = depth
+
 def hook_Cryptodome(finder, module):
     """pycryptodomex distributes the same package as pycryptodome under a different package name"""
     hook_Crypto(finder, module)
